@@ -36,6 +36,7 @@
 #include <QDomElement>
 #include <QTextStream>
 #include <QEvent>
+#include <QMimeData>
 #include <QTimer>
 #include <stdlib.h>
 #include <unistd.h>
@@ -522,8 +523,7 @@ void CGroupList::merge(const QString &file)
 
 void CGroupList::clear()
 {
-    beginRemoveRows(QModelIndex(), 0, itsGroups.count());
-    endRemoveRows();
+    beginResetModel();
     itsGroups.removeFirst(); // Remove all
     if(itsSpecialGroups[CGroupListItem::SYSTEM])
     {
@@ -541,6 +541,7 @@ void CGroupList::clear()
         itsGroups.append(itsSpecialGroups[CGroupListItem::SYSTEM]);
     }
     // Dont add 'Unclassif' until we have some user groups
+    endResetModel();
 }
 
 QModelIndex CGroupList::index(CGroupListItem::EType t)
@@ -752,7 +753,7 @@ class CGroupListViewDelegate : public QStyledItemDelegate
     CGroupListViewDelegate(QObject *p) : QStyledItemDelegate(p) { }
     virtual ~CGroupListViewDelegate() { }
 
-    void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &idx) const Q_DECL_OVERRIDE
+    void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &idx) const override
     {
         CGroupListItem       *grp=static_cast<CGroupListItem *>(idx.internalPointer());
         QStyleOptionViewItem opt(option);
@@ -770,7 +771,7 @@ class CGroupListViewDelegate : public QStyledItemDelegate
         }
     }
 
-    QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &idx) const Q_DECL_OVERRIDE
+    QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &idx) const override
     {
         QSize sz(QStyledItemDelegate::sizeHint(option, idx));
 
@@ -787,7 +788,7 @@ class CGroupListViewDelegate : public QStyledItemDelegate
                Qt::Key_Enter==event->key() || Qt::Key_Return==event->key();
     }
     
-    bool eventFilter(QObject *editor, QEvent *event) Q_DECL_OVERRIDE
+    bool eventFilter(QObject *editor, QEvent *event) override
     {
         if(editor && event && QEvent::KeyPress==event->type() && isCloseEvent(static_cast<QKeyEvent *>(event)) &&
            qobject_cast<QLineEdit *>(editor))
